```{toctree}
---
caption: Contents
hidden:
---
   Introduction <self>
   API Reference <api/api.md>
   Change Log <changelog.md>
   Development <development.md>
   Index <genindex>
```

```{include} ../README.md
:relative-docs: docs/
```
